Arguments verification for cst_deliv_duration.
cst_deliv_duration.verif_args(
Rx_deliv,
Rx_drug_code,
Rx_deliv_dur,
Cst_deliv_dur,
Cst_drug_code,
Cst_duration
)Name of the table listing all prescription drugs delivered.
Column name of Rx_deliv that contains the drug unique identifier.
Column name of the constant treatment duration in the Rx_deliv table.
Name of the table that contains the constant delivery durations that will overwrite that in the Rx_deliv table for the specified drug codes.
Column name of Cst_deliv_dur that contains the drug unique identifier (same format as Rx_drug_code).
Column name of the constant treatment duration in the Cst_deliv_dur table (same format as Rx_deliv_dur).
Messages, warnings or errors