Arguments verification for drug_bkdn.
drug_bkdn.verif_args(
Rx_deliv,
Rx_drug_code,
Combn_drugs,
Combn_drug_code,
Combn_act_code
)Name of the table listing all prescription drugs deliveries.
Column name of Rx_deliv that contains the combination drug unique identifiers (any format).
Name of the correspondence table listing all elementary active ingredients that make up each combination drug.
Column name of Combn_drugs that contains the combination drug unique identifiers (same format as Rx_drug_code).
Column name of elementary active ingredients that is present in Combn_drugs (same format as Rx_drug_code).
Messages, warnings or errors